@@ -22,7 +22,23 @@ _ESTIMATOR_FAMILY_ORDER = [
 
 
 class IterativeAlgorithm(AutoMLAlgorithm):
-    """An automl algorithm which first fits a base round of pipelines with default parameters, then does a round of parameter tuning on each pipeline in order of performance."""
+    """
+    An automl algorithm which first fits a base round of pipelines with default parameters, then does a round of parameter tuning on each pipeline in order of performance.
+
+    Arguments:
+        allowed_pipelines (list(class)): A list of PipelineBase instances indicating the pipelines allowed in the search. The default of None indicates all pipelines for this problem type are allowed.
+        max_iterations (int): The maximum number of iterations to be evaluated.
+        tuner_class (class): A subclass of Tuner, to be used to find parameters for each pipeline. The default of None indicates the SKOptTuner will be used.
+        random_seed (int): Seed for the random number generator. Defaults to 0.
+        pipelines_per_batch (int): The number of pipelines to be evaluated in each batch, after the first batch. Defaults to 5.
+        n_jobs (int or None): Non-negative integer describing level of parallelism used for pipelines. Defaults to None.
+        number_features (int): The number of columns in the input features. Defaults to None.
+        ensembling (boolean): If True, runs ensembling in a separate batch after every allowed pipeline class has been iterated over. Defaults to False.
+        text_in_ensembling (boolean): If True and ensembling is True, then n_jobs will be set to 1 to avoid downstream sklearn stacking issues related to nltk. Defaults to None.
+        pipeline_params (dict or None): Pipeline-level parameters that should be passed to the proposed pipelines. Defaults to None.
+        custom_hyperparameters (dict or None): Custom hyperparameter ranges specified for pipelines to iterate over. Defaults to None.
+        _estimator_family_order (list(ModelFamily) or None): specify the sort order for the first batch. Defaults to None, which uses _ESTIMATOR_FAMILY_ORDER.
+    """
 
     def __init__(
         self,
@@ -46,14 +62,14 @@ class IterativeAlgorithm(AutoMLAlgorithm):
             max_iterations (int): The maximum number of iterations to be evaluated.
             tuner_class (class): A subclass of Tuner, to be used to find parameters for each pipeline. The default of None indicates the SKOptTuner will be used.
             random_seed (int): Seed for the random number generator. Defaults to 0.
-            pipelines_per_batch (int): The number of pipelines to be evaluated in each batch, after the first batch.
-            n_jobs (int or None): Non-negative integer describing level of parallelism used for pipelines.
-            number_features (int): The number of columns in the input features.
+            pipelines_per_batch (int): The number of pipelines to be evaluated in each batch, after the first batch. Defaults to 5.
+            n_jobs (int or None): Non-negative integer describing level of parallelism used for pipelines. Defaults to -1.
+            number_features (int): The number of columns in the input features. Defaults to None.
             ensembling (boolean): If True, runs ensembling in a separate batch after every allowed pipeline class has been iterated over. Defaults to False.
-            text_in_ensembling (boolean): If True and ensembling is True, then n_jobs will be set to 1 to avoid downstream sklearn stacking issues related to nltk.
-            pipeline_params (dict or None): Pipeline-level parameters that should be passed to the proposed pipelines.
-            custom_hyperparameters (dict or None): Custom hyperparameter ranges specified for pipelines to iterate over.
-            _estimator_family_order (list(ModelFamily) or None): specify the sort order for the first batch. Defaults to _ESTIMATOR_FAMILY_ORDER.
+            text_in_ensembling (boolean): If True and ensembling is True, then n_jobs will be set to 1 to avoid downstream sklearn stacking issues related to nltk. Defaults to None.
+            pipeline_params (dict or None): Pipeline-level parameters that should be passed to the proposed pipelines. Defaults to None.
+            custom_hyperparameters (dict or None): Custom hyperparameter ranges specified for pipelines to iterate over. Defaults to None.
+            _estimator_family_order (list(ModelFamily) or None): specify the sort order for the first batch. Defaults to None, which uses _ESTIMATOR_FAMILY_ORDER.
         """
         self._estimator_family_order = (
             _estimator_family_order or _ESTIMATOR_FAMILY_ORDER
@@ -234,7 +250,11 @@ class IterativeAlgorithm(AutoMLAlgorithm):
         if "pipeline" in self._pipeline_params:
             parameters["pipeline"] = self._pipeline_params["pipeline"]
 
-        for name, component_class in pipeline.linearized_component_graph:
+        for (
+            name,
+            component_instance,
+        ) in pipeline.component_graph.component_instances.items():
+            component_class = type(component_instance)
             component_parameters = proposed_parameters.get(name, {})
             init_params = inspect.signature(component_class.__init__).parameters
             # For first batch, pass the pipeline params to the components that need them
