@@ -56,11 +56,7 @@ from evalml.problem_types import (
     is_time_series,
 )
 from evalml.tuners import SKOptTuner
-from evalml.utils import (
-    _put_into_original_order,
-    convert_to_seconds,
-    infer_feature_types,
-)
+from evalml.utils import convert_to_seconds, infer_feature_types
 from evalml.utils.logger import (
     get_logger,
     log_subtitle,
@@ -71,7 +67,14 @@ from evalml.utils.logger import (
 logger = get_logger(__file__)
 
 
-def search(X_train=None, y_train=None, problem_type=None, objective="auto", **kwargs):
+def search(
+    X_train=None,
+    y_train=None,
+    problem_type=None,
+    objective="auto",
+    problem_configuration=None,
+    **kwargs,
+):
     """Given data and configuration, run an automl search.
 
     This method will run EvalML's default suite of data checks. If the data checks produce errors, the data check results will be returned before running the automl search. In that case we recommend you alter your data to address these errors and try again.
@@ -92,6 +95,9 @@ def search(X_train=None, y_train=None, problem_type=None, objective="auto", **kw
             - LogLossMulticlass for multiclass classification problems, and
             - R2 for regression problems.
 
+        problem_configuration (dict): Additional parameters needed to configure the search. For example,
+        in time series problems, values should be passed in for the date_index, gap, and max_delay variables.
+
     Other keyword arguments which are provided will be passed to AutoMLSearch.
 
     Returns:
@@ -100,6 +106,22 @@ def search(X_train=None, y_train=None, problem_type=None, objective="auto", **kw
     X_train = infer_feature_types(X_train)
     y_train = infer_feature_types(y_train)
     problem_type = handle_problem_types(problem_type)
+
+    datetime_column = None
+    if is_time_series(problem_type):
+        if problem_configuration:
+            if "date_index" in problem_configuration:
+                datetime_column = problem_configuration["date_index"]
+            else:
+                raise ValueError(
+                    "For the default data checks to run in time series, date_index has to be passed in problem_configuration. "
+                    f"Received {problem_configuration}"
+                )
+        else:
+            raise ValueError(
+                "For the default data checks to run in time series, the problem_configuration parameter must be specified."
+            )
+
     if objective == "auto":
         objective = get_default_primary_search_objective(problem_type)
     objective = get_objective(objective, return_instance=False)
@@ -115,7 +137,9 @@ def search(X_train=None, y_train=None, problem_type=None, objective="auto", **kw
         }
     )
 
-    data_checks = DefaultDataChecks(problem_type=problem_type, objective=objective)
+    data_checks = DefaultDataChecks(
+        problem_type=problem_type, objective=objective, datetime_column=datetime_column
+    )
     data_check_results = data_checks.validate(X_train, y=y_train)
     if len(data_check_results.get("errors", [])):
         return None, data_check_results
@@ -481,6 +505,16 @@ class AutoMLSearch:
             allowed_estimators = get_estimators(
                 self.problem_type, self.allowed_model_families
             )
+            if (
+                is_time_series(self.problem_type)
+                and parameters["pipeline"]["date_index"]
+            ):
+                if pd.infer_freq(X_train[parameters["pipeline"]["date_index"]]) == "MS":
+                    allowed_estimators = [
+                        estimator
+                        for estimator in allowed_estimators
+                        if estimator.name != "ARIMA Regressor"
+                    ]
             logger.debug(
                 f"allowed_estimators set to {[estimator.name for estimator in allowed_estimators]}"
             )
@@ -495,9 +529,7 @@ class AutoMLSearch:
             unknown_columns = list(
                 self.X_train.ww.select("unknown", return_schema=True).columns
             )
-            index_and_unknown_columns = _put_into_original_order(
-                self.X_train, index_and_unknown_columns
-            )
+            index_and_unknown_columns = index_and_unknown_columns
             if len(index_and_unknown_columns) > 0 and drop_columns is None:
                 parameters["Drop Columns Transformer"] = {
                     "columns": index_and_unknown_columns
@@ -713,7 +745,7 @@ class AutoMLSearch:
         return search_desc + rankings_desc
 
     def _validate_problem_configuration(self, problem_configuration=None):
-        if self.problem_type in [ProblemTypes.TIME_SERIES_REGRESSION]:
+        if is_time_series(self.problem_type):
             required_parameters = {"date_index", "gap", "max_delay"}
             if not problem_configuration or not all(
                 p in problem_configuration for p in required_parameters
@@ -1091,7 +1123,7 @@ class AutoMLSearch:
             )
             percent_better_than_baseline[obj_name] = percent_better
 
-        high_variance_cv = self._check_for_high_variance(pipeline, cv_score, cv_sd)
+        high_variance_cv = self._check_for_high_variance(pipeline, cv_scores)
 
         pipeline_id = len(self._results["pipeline_results"])
         self._results["pipeline_results"][pipeline_id] = {
@@ -1147,17 +1179,22 @@ class AutoMLSearch:
             )
         return pipeline_id
 
-    def _check_for_high_variance(self, pipeline, cv_mean, cv_std, threshold=0.2):
+    def _check_for_high_variance(self, pipeline, cv_scores, threshold=0.5):
         """Checks cross-validation scores and logs a warning if variance is higher than specified threshhold."""
         pipeline_name = pipeline.name
 
         high_variance_cv = False
-        if cv_std != 0 and cv_mean != 0:
-            high_variance_cv = bool(abs(cv_std / cv_mean) > threshold)
-        if high_variance_cv:
+        allowed_range = (
+            self.objective.expected_range[1] - self.objective.expected_range[0]
+        )
+        if allowed_range == float("inf"):
+            return high_variance_cv
+        cv_range = max(cv_scores) - min(cv_scores)
+        if cv_range >= threshold * allowed_range:
             logger.warning(
                 f"\tHigh coefficient of variation (cv >= {threshold}) within cross validation scores.\n\t{pipeline_name} may not perform as estimated on unseen data."
             )
+            high_variance_cv = True
         return high_variance_cv
 
     def get_pipeline(self, pipeline_id):
