@@ -1,14 +1,12 @@
 class DataCheckAction:
-    """Base class for all DataCheckActions."""
+    """A recommended action returned by a DataCheck.
+
+    Arguments:
+        action_code (DataCheckActionCode): Action code associated with the action.
+        metadata (dict, optional): Additional useful information associated with the action. Defaults to None.
+    """
 
     def __init__(self, action_code, metadata=None):
-        """
-        A recommended action returned by a DataCheck.
-
-        Arguments:
-            action_code (DataCheckActionCode): Action code associated with the action.
-            metadata (dict, optional): Additional useful information associated with the action. Defaults to None.
-        """
         self.action_code = action_code
         self.metadata = metadata or {}
 
