@@ -40,6 +40,9 @@ class ModelFamily(Enum):
     BASELINE = "baseline"
     """Baseline model family."""
 
+    PROPHET = "prophet"
+    """Prophet model family."""
+
     NONE = "none"
     """None"""
 
@@ -57,8 +60,10 @@ class ModelFamily(Enum):
             ModelFamily.BASELINE.name: "Baseline",
             ModelFamily.ENSEMBLE.name: "Ensemble",
             ModelFamily.ARIMA.name: "ARIMA",
+            ModelFamily.PROPHET.name: "Prophet",
             ModelFamily.NONE.name: "None",
         }
+
         return model_family_dict[self.name]
 
     def __repr__(self):
