@@ -10,19 +10,39 @@ import pandas as pd
 from evalml.exceptions import PipelineScoreError
 from evalml.model_family import ModelFamily
 from evalml.model_understanding.prediction_explanations._report_creator_factory import (
-    _report_creator_factory
+    _report_creator_factory,
 )
 from evalml.problem_types import ProblemTypes, is_regression, is_time_series
 from evalml.utils import infer_feature_types
 from evalml.utils.gen_utils import drop_rows_with_nans
 
 # Container for all of the pipeline-related data we need to create reports. Helps standardize APIs of report makers.
-_ReportData = namedtuple("ReportData", ["pipeline", "pipeline_features", "input_features",
-                                        "y_true", "y_pred", "y_pred_values", "errors", "index_list", "metric"])
+_ReportData = namedtuple(
+    "ReportData",
+    [
+        "pipeline",
+        "pipeline_features",
+        "input_features",
+        "y_true",
+        "y_pred",
+        "y_pred_values",
+        "errors",
+        "index_list",
+        "metric",
+    ],
+)
 
 
-def explain_predictions(pipeline, input_features, y, indices_to_explain, top_k_features=3, include_shap_values=False,
-                        output_format="text"):
+def explain_predictions(
+    pipeline,
+    input_features,
+    y,
+    indices_to_explain,
+    top_k_features=3,
+    include_shap_values=False,
+    include_expected_value=False,
+    output_format="text",
+):
     """Creates a report summarizing the top contributing features for each data point in the input features.
 
     XGBoost and Stacked Ensemble models, as well as CatBoost multiclass classifiers, are not currently supported.
@@ -35,6 +55,7 @@ def explain_predictions(pipeline, input_features, y, indices_to_explain, top_k_f
         top_k_features (int): How many of the highest/lowest contributing feature to include in the table for each
             data point.  Default is 3.
         include_shap_values (bool): Whether SHAP values should be included in the table. Default is False.
+        include_expected_value (bool): Whether the expected value should be included in the table. Default is False.
         output_format (str): Either "text", "dict", or "dataframe". Default is "text".
 
     Returns:
@@ -53,18 +74,36 @@ def explain_predictions(pipeline, input_features, y, indices_to_explain, top_k_f
     if input_features.empty:
         raise ValueError("Parameter input_features must be a non-empty dataframe.")
     if output_format not in {"text", "dict", "dataframe"}:
-        raise ValueError(f"Parameter output_format must be either text, dict, or dataframe. Received {output_format}")
+        raise ValueError(
+            f"Parameter output_format must be either text, dict, or dataframe. Received {output_format}"
+        )
     if any([x < 0 or x >= len(input_features) for x in indices_to_explain]):
-        raise ValueError(f"Explained indices should be between 0 and {len(input_features) - 1}")
+        raise ValueError(
+            f"Explained indices should be between 0 and {len(input_features) - 1}"
+        )
 
     pipeline_features = pipeline.compute_estimator_features(input_features, y)
 
-    data = _ReportData(pipeline, pipeline_features, input_features, y_true=y, y_pred=None,
-                       y_pred_values=None, errors=None, index_list=indices_to_explain, metric=None)
+    data = _ReportData(
+        pipeline,
+        pipeline_features,
+        input_features,
+        y_true=y,
+        y_pred=None,
+        y_pred_values=None,
+        errors=None,
+        index_list=indices_to_explain,
+        metric=None,
+    )
 
-    report_creator = _report_creator_factory(data, report_type="explain_predictions",
-                                             output_format=output_format, top_k_features=top_k_features,
-                                             include_shap_values=include_shap_values)
+    report_creator = _report_creator_factory(
+        data,
+        report_type="explain_predictions",
+        output_format=output_format,
+        top_k_features=top_k_features,
+        include_shap_values=include_shap_values,
+        include_expected_value=include_expected_value,
+    )
     return report_creator(data)
 
 
@@ -81,15 +120,24 @@ def _update_progress(start_time, current_time, progress_stage, callback_function
 
 
 class ExplainPredictionsStage(Enum):
-    PREPROCESSING_STAGE = "preprocessing_stage",
-    PREDICT_STAGE = "predict_stage",
-    COMPUTE_FEATURE_STAGE = "compute_feature_stage",
-    COMPUTE_SHAP_VALUES_STAGE = "compute_shap_value_stage",
+    PREPROCESSING_STAGE = "preprocessing_stage"
+    PREDICT_STAGE = "predict_stage"
+    COMPUTE_FEATURE_STAGE = "compute_feature_stage"
+    COMPUTE_SHAP_VALUES_STAGE = "compute_shap_value_stage"
     DONE = "done"
 
 
-def explain_predictions_best_worst(pipeline, input_features, y_true, num_to_explain=5, top_k_features=3,
-                                   include_shap_values=False, metric=None, output_format="text", callback=None):
+def explain_predictions_best_worst(
+    pipeline,
+    input_features,
+    y_true,
+    num_to_explain=5,
+    top_k_features=3,
+    include_shap_values=False,
+    metric=None,
+    output_format="text",
+    callback=None,
+):
     """Creates a report summarizing the top contributing features for the best and worst points in the dataset as measured by error to true labels.
 
     XGBoost and Stacked Ensemble models, as well as CatBoost multiclass classifiers, are not currently supported.
@@ -121,25 +169,35 @@ def explain_predictions_best_worst(pipeline, input_features, y_true, num_to_expl
         ValueError: if an output_format outside of "text", "dict" or "dataframe is provided.
     """
     start_time = timer()
-    _update_progress(start_time, timer(), ExplainPredictionsStage.PREPROCESSING_STAGE, callback)
+    _update_progress(
+        start_time, timer(), ExplainPredictionsStage.PREPROCESSING_STAGE, callback
+    )
 
     input_features = infer_feature_types(input_features)
     y_true = infer_feature_types(y_true)
 
     if not (input_features.shape[0] >= num_to_explain * 2):
-        raise ValueError(f"Input features must be a dataframe with more than {num_to_explain * 2} rows! "
-                         "Convert to a dataframe and select a smaller value for num_to_explain if you do not have "
-                         "enough data.")
+        raise ValueError(
+            f"Input features must be a dataframe with more than {num_to_explain * 2} rows! "
+            "Convert to a dataframe and select a smaller value for num_to_explain if you do not have "
+            "enough data."
+        )
     if y_true.shape[0] != input_features.shape[0]:
-        raise ValueError("Parameters y_true and input_features must have the same number of data points. Received: "
-                         f"true labels: {y_true.shape[0]} and {input_features.shape[0]}")
+        raise ValueError(
+            "Parameters y_true and input_features must have the same number of data points. Received: "
+            f"true labels: {y_true.shape[0]} and {input_features.shape[0]}"
+        )
     if output_format not in {"text", "dict", "dataframe"}:
-        raise ValueError(f"Parameter output_format must be either text, dict, or dataframe. Received {output_format}")
+        raise ValueError(
+            f"Parameter output_format must be either text, dict, or dataframe. Received {output_format}"
+        )
     if pipeline.model_family == ModelFamily.ENSEMBLE:
         raise ValueError("Cannot explain predictions for a stacked ensemble pipeline")
     if not metric:
         metric = DEFAULT_METRICS[pipeline.problem_type]
-    _update_progress(start_time, timer(), ExplainPredictionsStage.PREDICT_STAGE, callback)
+    _update_progress(
+        start_time, timer(), ExplainPredictionsStage.PREDICT_STAGE, callback
+    )
 
     try:
         if is_regression(pipeline.problem_type):
@@ -157,31 +215,54 @@ def explain_predictions_best_worst(pipeline, input_features, y_true, num_to_expl
             else:
                 y_pred = pipeline.predict_proba(input_features)
                 y_pred_values = pipeline.predict(input_features)
-            y_true_no_nan, y_pred_no_nan, y_pred_values_no_nan = drop_rows_with_nans(y_true, y_pred, y_pred_values)
+            y_true_no_nan, y_pred_no_nan, y_pred_values_no_nan = drop_rows_with_nans(
+                y_true, y_pred, y_pred_values
+            )
             errors = metric(pipeline._encode_targets(y_true_no_nan), y_pred_no_nan)
     except Exception as e:
         tb = traceback.format_tb(sys.exc_info()[2])
-        raise PipelineScoreError(exceptions={metric.__name__: (e, tb)}, scored_successfully={})
+        raise PipelineScoreError(
+            exceptions={metric.__name__: (e, tb)}, scored_successfully={}
+        )
 
     errors = pd.Series(errors, index=y_pred_no_nan.index)
     sorted_scores = errors.sort_values()
     best_indices = sorted_scores.index[:num_to_explain]
     worst_indices = sorted_scores.index[-num_to_explain:]
     index_list = best_indices.tolist() + worst_indices.tolist()
-    _update_progress(start_time, timer(), ExplainPredictionsStage.COMPUTE_FEATURE_STAGE, callback)
+    _update_progress(
+        start_time, timer(), ExplainPredictionsStage.COMPUTE_FEATURE_STAGE, callback
+    )
 
     pipeline_features = pipeline.compute_estimator_features(input_features, y_true)
 
-    _update_progress(start_time, timer(), ExplainPredictionsStage.COMPUTE_SHAP_VALUES_STAGE, callback)
+    _update_progress(
+        start_time, timer(), ExplainPredictionsStage.COMPUTE_SHAP_VALUES_STAGE, callback
+    )
 
-    data = _ReportData(pipeline, pipeline_features, input_features, y_true, y_pred, y_pred_values, errors, index_list, metric)
+    data = _ReportData(
+        pipeline,
+        pipeline_features,
+        input_features,
+        y_true,
+        y_pred,
+        y_pred_values,
+        errors,
+        index_list,
+        metric,
+    )
 
-    report_creator = _report_creator_factory(data, report_type="explain_predictions_best_worst",
-                                             output_format=output_format, top_k_features=top_k_features,
-                                             include_shap_values=include_shap_values, num_to_explain=num_to_explain)
+    report_creator = _report_creator_factory(
+        data,
+        report_type="explain_predictions_best_worst",
+        output_format=output_format,
+        top_k_features=top_k_features,
+        include_shap_values=include_shap_values,
+        num_to_explain=num_to_explain,
+        include_expected_value=True,
+    )
 
     _update_progress(start_time, timer(), ExplainPredictionsStage.DONE, callback)
-
     return report_creator(data)
 
 
@@ -209,13 +290,17 @@ def cross_entropy(y_true, y_pred_proba):
         np.ndarray
     """
     n_data_points = y_pred_proba.shape[0]
-    log_likelihood = -np.log(y_pred_proba.values[range(n_data_points), y_true.values.astype("int")])
+    log_likelihood = -np.log(
+        y_pred_proba.values[range(n_data_points), y_true.values.astype("int")]
+    )
     return log_likelihood
 
 
-DEFAULT_METRICS = {ProblemTypes.BINARY: cross_entropy,
-                   ProblemTypes.MULTICLASS: cross_entropy,
-                   ProblemTypes.REGRESSION: abs_error,
-                   ProblemTypes.TIME_SERIES_BINARY: cross_entropy,
-                   ProblemTypes.TIME_SERIES_MULTICLASS: cross_entropy,
-                   ProblemTypes.TIME_SERIES_REGRESSION: abs_error}
+DEFAULT_METRICS = {
+    ProblemTypes.BINARY: cross_entropy,
+    ProblemTypes.MULTICLASS: cross_entropy,
+    ProblemTypes.REGRESSION: abs_error,
+    ProblemTypes.TIME_SERIES_BINARY: cross_entropy,
+    ProblemTypes.TIME_SERIES_MULTICLASS: cross_entropy,
+    ProblemTypes.TIME_SERIES_REGRESSION: abs_error,
+}
