@@ -1,3 +1,4 @@
+import inspect
 import warnings
 
 import networkx as nx
@@ -7,10 +8,14 @@ from networkx.algorithms.dag import topological_sort
 from networkx.exception import NetworkXUnfeasible
 
 from evalml.exceptions.exceptions import (
+    MethodPropertyNotFoundError,
     MissingComponentError,
     ParameterNotUsedWarning,
 )
 from evalml.pipelines.components import ComponentBase, Estimator, Transformer
+from evalml.pipelines.components.transformers.samplers.base_sampler import (
+    BaseSampler,
+)
 from evalml.pipelines.components.transformers.transformer import (
     TargetTransformer,
 )
@@ -61,13 +66,35 @@ class ComponentGraph:
                 component_input.endswith(".x") or component_input == "X"
                 for component_input in component_inputs
             )
-            has_target_input = any(
+            num_target_inputs = sum(
                 component_input.endswith(".y") or component_input == "y"
                 for component_input in component_inputs
             )
-            if not (has_feature_input and has_target_input):
+            if not has_feature_input:
                 raise ValueError(
-                    "All edges must be specified as either an input feature (.x) or input target (.y)."
+                    "All components must have at least one input feature (.x/X) edge."
+                )
+            if num_target_inputs != 1:
+                raise ValueError(
+                    "All components must have exactly one target (.y/y) edge."
+                )
+
+            def check_all_inputs_have_correct_syntax(edge):
+                return not (
+                    edge.endswith(".y")
+                    or edge == "y"
+                    or edge.endswith(".x")
+                    or edge == "X"
+                )
+
+            if (
+                len(
+                    list(filter(check_all_inputs_have_correct_syntax, component_inputs))
+                )
+                != 0
+            ):
+                raise ValueError(
+                    "All edges must be specified as either an input feature ('X'/.x) or input target ('y'/.y)."
                 )
 
     @property
@@ -94,7 +121,8 @@ class ComponentGraph:
 
         Arguments:
             parameters (dict): Dictionary with component names as keys and dictionary of that component's parameters as values.
-                               An empty dictionary {} or None implies using all default values for component parameters.
+                               An empty dictionary {} or None implies using all default values for component parameters. If a component
+                               in the component graph is already instantiated, it will not use any of its parameters defined in this dictionary.
         """
         if self._is_instantiated:
             raise ValueError(
@@ -109,27 +137,29 @@ class ComponentGraph:
         component_instances = {}
         for component_name, component_class in self.component_instances.items():
             component_parameters = parameters.get(component_name, {})
-            try:
-                new_component = component_class(
-                    **component_parameters, random_seed=self.random_seed
-                )
-            except (ValueError, TypeError) as e:
-                self._is_instantiated = False
-                err = "Error received when instantiating component {} with the following arguments {}".format(
-                    component_name, component_parameters
-                )
-                raise ValueError(err) from e
-
-            component_instances[component_name] = new_component
+            if inspect.isclass(component_class):
+                try:
+                    new_component = component_class(
+                        **component_parameters, random_seed=self.random_seed
+                    )
+                except (ValueError, TypeError) as e:
+                    self._is_instantiated = False
+                    err = "Error received when instantiating component {} with the following arguments {}".format(
+                        component_name, component_parameters
+                    )
+                    raise ValueError(err) from e
+                component_instances[component_name] = new_component
+            elif isinstance(component_class, ComponentBase):
+                component_instances[component_name] = component_class
         self.component_instances = component_instances
         return self
 
     def fit(self, X, y):
-        """Fit each component in the graph
+        """Fit each component in the graph.
 
         Arguments:
-            X (pd.DataFrame): The input training data of shape [n_samples, n_features]
-            y (pd.Series): The target training data of length [n_samples]
+            X (pd.DataFrame): The input training data of shape [n_samples, n_features].
+            y (pd.Series): The target training data of length [n_samples].
         """
         X = infer_feature_types(X)
         y = infer_feature_types(y)
@@ -138,11 +168,11 @@ class ComponentGraph:
         return self
 
     def fit_features(self, X, y):
-        """Fit all components save the final one, usually an estimator
+        """Fit all components save the final one, usually an estimator.
 
         Arguments:
-            X (pd.DataFrame): The input training data of shape [n_samples, n_features]
-            y (pd.Series): The target training data of length [n_samples]
+            X (pd.DataFrame): The input training data of shape [n_samples, n_features].
+            y (pd.Series): The target training data of length [n_samples].
 
         Returns:
             pd.DataFrame: Transformed values.
@@ -151,10 +181,10 @@ class ComponentGraph:
 
     def compute_final_component_features(self, X, y=None):
         """Transform all components save the final one, and gathers the data from any number of parents
-        to get all the information that should be fed to the final component
+        to get all the information that should be fed to the final component.
 
         Arguments:
-            X (pd.DataFrame): Data of shape [n_samples, n_features]
+            X (pd.DataFrame): Data of shape [n_samples, n_features].
             y (pd.Series): The target training data of length [n_samples]. Defaults to None.
 
         Returns:
@@ -163,11 +193,11 @@ class ComponentGraph:
         return self._fit_transform_features_helper(False, X, y)
 
     def _fit_transform_features_helper(self, needs_fitting, X, y=None):
-        """Helper function that transforms the input data based on the component graph components.
+        """Transform all components save the final one, and returns the data that should be fed to the final component, usually an estimator.
 
         Arguments:
             needs_fitting (boolean): Determines if components should be fit.
-            X (pd.DataFrame): Data of shape [n_samples, n_features]
+            X (pd.DataFrame): Data of shape [n_samples, n_features].
             y (pd.Series): The target training data of length [n_samples]. Defaults to None.
 
         Returns:
@@ -180,36 +210,66 @@ class ComponentGraph:
         component_outputs = self._compute_features(
             self.compute_order[:-1], X, y=y, fit=needs_fitting
         )
-        final_component_inputs = []
-
-        parent_inputs = [
-            parent_input
-            for parent_input in self.get_inputs(self.compute_order[-1])
-            if parent_input[-2:] != ".y"
-        ]
-        for parent in parent_inputs:
-            parent_output = component_outputs.get(
-                parent, component_outputs.get(f"{parent}.x")
-            )
-            if isinstance(parent_output, pd.Series):
-                parent_output = pd.DataFrame(parent_output, columns=[parent])
-                parent_output = infer_feature_types(parent_output)
-            if parent_output is not None:
-                final_component_inputs.append(parent_output)
-        concatted = ww.utils.concat_columns(
-            [component_input for component_input in final_component_inputs]
+        x_inputs, _ = self._consolidate_inputs_for_component(
+            component_outputs, self.compute_order[-1], X, y
         )
         if needs_fitting:
             self.input_feature_names.update(
-                {self.compute_order[-1]: list(concatted.columns)}
+                {self.compute_order[-1]: list(x_inputs.columns)}
             )
-        return concatted
+        return x_inputs
+
+    def _consolidate_inputs_for_component(
+        self, component_outputs, component, X, y=None
+    ):
+        x_inputs = []
+        y_input = None
+        for parent_input in self.get_inputs(component):
+            if parent_input == "y":
+                y_input = y
+            elif parent_input == "X":
+                x_inputs.append(X)
+            elif parent_input.endswith(".y"):
+                y_input = component_outputs[parent_input]
+            elif parent_input.endswith(".x"):
+                parent_x = component_outputs[parent_input]
+                if isinstance(parent_x, pd.Series):
+                    parent_x = parent_x.rename(parent_input)
+                x_inputs.append(parent_x)
+        x_inputs = ww.concat_columns(x_inputs)
+        return x_inputs, y_input
+
+    def transform(self, X, y=None):
+        """Transform the input using the component graph.
+
+        Arguments:
+            X (pd.DataFrame): Input features of shape [n_samples, n_features].
+            y (pd.Series): The target data of length [n_samples]. Defaults to None.
+
+        Returns:
+            pd.DataFrame: Transformed output.
+        """
+        if len(self.compute_order) == 0:
+            return infer_feature_types(X)
+        final_component_name = self.compute_order[-1]
+        final_component_instance = self.get_last_component()
+        if not isinstance(final_component_instance, Transformer):
+            raise ValueError(
+                "Cannot call transform() on a component graph because the final component is not a Transformer."
+            )
+
+        outputs = self._compute_features(self.compute_order, X, y, False)
+        output_x = infer_feature_types(outputs.get(f"{final_component_name}.x"))
+        output_y = outputs.get(f"{final_component_name}.y", None)
+        if output_y is not None:
+            return output_x, output_y
+        return output_x
 
     def predict(self, X):
         """Make predictions using selected features.
 
         Arguments:
-            X (pd.DataFrame): Data of shape [n_samples, n_features]
+            X (pd.DataFrame): Input features of shape [n_samples, n_features].
 
         Returns:
             pd.Series: Predicted values.
@@ -217,10 +277,13 @@ class ComponentGraph:
         if len(self.compute_order) == 0:
             return infer_feature_types(X)
         final_component = self.compute_order[-1]
+        final_component_instance = self.get_last_component()
+        if not isinstance(final_component_instance, Estimator):
+            raise ValueError(
+                "Cannot call predict() on a component graph because the final component is not an Estimator."
+            )
         outputs = self._compute_features(self.compute_order, X)
-        return infer_feature_types(
-            outputs.get(final_component, outputs.get(f"{final_component}.x"))
-        )
+        return infer_feature_types(outputs.get(f"{final_component}.x"))
 
     def _compute_features(self, component_list, X, y=None, fit=False):
         """Transforms the data by applying the given components.
@@ -228,19 +291,20 @@ class ComponentGraph:
         Arguments:
             component_list (list): The list of component names to compute.
             X (pd.DataFrame): Input data to the pipeline to transform.
-            y (pd.Series): The target training data of length [n_samples]
-            fit (bool): Whether to fit the estimators as well as transform it.
+            y (pd.Series): The target training data of length [n_samples].
+            fit (boolean): Whether to fit the estimators as well as transform it.
                         Defaults to False.
 
         Returns:
-            dict: Outputs from each component
+            dict: Outputs from each component.
         """
         X = infer_feature_types(X)
         if y is not None:
             y = infer_feature_types(y)
-        most_recent_y = y
+
         if len(component_list) == 0:
             return X
+
         output_cache = {}
         for component_name in component_list:
             component_instance = self.get_component(component_name)
@@ -248,41 +312,21 @@ class ComponentGraph:
                 raise ValueError(
                     "All components must be instantiated before fitting or predicting"
                 )
-            x_inputs = []
-            y_input = None
 
-            for parent_input in self.get_inputs(component_name):
-                if parent_input[-2:] == ".y" or parent_input == "y":
-                    if y_input is not None:
-                        raise ValueError(
-                            f"Cannot have multiple `y` parents for a single component {component_name}"
-                        )
-                    y_input = (
-                        output_cache[parent_input] if parent_input[-2:] == ".y" else y
-                    )
-
-                else:
-                    if parent_input == "X":
-                        x_inputs.append(X)
-                    else:
-                        parent_x = output_cache.get(
-                            parent_input, output_cache.get(f"{parent_input}.x")
-                        )
-                        if isinstance(parent_x, pd.Series):
-                            parent_x = parent_x.rename(parent_input)
-                        x_inputs.append(parent_x)
-            input_x, input_y = self._consolidate_inputs(
-                x_inputs, y_input, X, most_recent_y
+            x_inputs, y_input = self._consolidate_inputs_for_component(
+                output_cache, component_name, X, y
             )
-            self.input_feature_names.update({component_name: list(input_x.columns)})
+            self.input_feature_names.update({component_name: list(x_inputs.columns)})
             if isinstance(component_instance, Transformer):
                 if fit:
-                    output = component_instance.fit_transform(input_x, input_y)
+                    output = component_instance.fit_transform(x_inputs, y_input)
+                elif isinstance(component_instance, BaseSampler):
+                    output = x_inputs, y_input
                 else:
-                    output = component_instance.transform(input_x, input_y)
+                    output = component_instance.transform(x_inputs, y_input)
+
                 if isinstance(output, tuple):
                     output_x, output_y = output[0], output[1]
-                    most_recent_y = output_y
                 else:
                     output_x = output
                     output_y = None
@@ -290,13 +334,27 @@ class ComponentGraph:
                 output_cache[f"{component_name}.y"] = output_y
             else:
                 if fit:
-                    component_instance.fit(input_x, input_y)
-                if not (
-                    fit and component_name == self.compute_order[-1]
-                ):  # Don't call predict on the final component during fit
-                    output = component_instance.predict(input_x)
-                else:
+                    component_instance.fit(x_inputs, y_input)
+                if fit and component_name == self.compute_order[-1]:
+                    # Don't call predict on the final component during fit
                     output = None
+                elif component_name != self.compute_order[-1]:
+                    try:
+                        output = component_instance.predict_proba(x_inputs)
+                        if isinstance(output, pd.DataFrame):
+                            if len(output.columns) == 2:
+                                # If it is a binary problem, drop the first column since both columns are colinear
+                                output = output.ww.drop(output.columns[0])
+                            output = output.ww.rename(
+                                {
+                                    col: f"Col {str(col)} {component_name}.x"
+                                    for col in output.columns
+                                }
+                            )
+                    except MethodPropertyNotFoundError:
+                        output = component_instance.predict(x_inputs)
+                else:
+                    output = component_instance.predict(x_inputs)
                 output_cache[f"{component_name}.x"] = output
         return output_cache
 
@@ -364,31 +422,6 @@ class ComponentGraph:
             if len(children)
         }
 
-    @staticmethod
-    def _consolidate_inputs(x_inputs, y_input, X, y):
-        """Combines any/all X and y inputs for a component, including handling defaults
-
-        Arguments:
-            x_inputs (list(pd.DataFrame)): Data to be used as X input for a component
-            y_input (pd.Series, None): If present, the Series to use as y input for a component, different from the original y
-            X (pd.DataFrame): The original X input, to be used if there is no parent X input
-            y (pd.Series): The original y input, to be used if there is no parent y input
-
-        Returns:
-            pd.DataFrame, pd.Series: The X and y transformed values to evaluate a component with
-        """
-        if len(x_inputs) == 0:
-            return_x = X
-        else:
-            return_x = ww.concat_columns(x_inputs)
-        return_y = y
-        if y_input is not None:
-            return_y = y_input
-
-        if return_y is not None:
-            return_y = infer_feature_types(return_y)
-        return return_x, return_y
-
     def get_component(self, component_name):
         """Retrieves a single component object from the graph.
 
@@ -415,10 +448,10 @@ class ComponentGraph:
         return self.get_component(last_component_name)
 
     def get_estimators(self):
-        """Gets a list of all the estimator components within this graph
+        """Gets a list of all the estimator components within this graph.
 
         Returns:
-            list: All estimator objects within the graph
+            list: All estimator objects within the graph.
         """
         if not isinstance(self.get_last_component(), ComponentBase):
             raise ValueError(
