@@ -66,7 +66,7 @@ class ExtraTreesRegressor(Estimator):
         min_weight_fraction_leaf=0.0,
         n_jobs=-1,
         random_seed=0,
-        **kwargs
+        **kwargs,
     ):
         parameters = {
             "n_estimators": n_estimators,
