@@ -7,7 +7,12 @@ from .feature_selection import (
 )
 from .imputers import PerColumnImputer, SimpleImputer, Imputer, TargetImputer
 from .scalers import StandardScaler
-from .samplers import Undersampler, SMOTESampler, SMOTENCSampler, SMOTENSampler
+from .samplers import (
+    Undersampler,
+    SMOTEOversampler,
+    SMOTENCOversampler,
+    SMOTENOversampler,
+)
 from .column_selectors import DropColumns, SelectColumns, SelectByType
 from .dimensionality_reduction import LinearDiscriminantAnalysis, PCA
 from .preprocessing import (
