@@ -6,3 +6,5 @@ from .text_featurizer import TextFeaturizer
 from .delayed_feature_transformer import DelayedFeatureTransformer
 from .featuretools import DFSTransformer
 from .polynomial_detrender import PolynomialDetrender
+from .log_transformer import LogTransformer
+from .transform_primitive_components import EmailFeaturizer, URLFeaturizer
