@@ -28,11 +28,11 @@ from evalml.pipelines.components import (  # noqa: F401
     LogTransformer,
     OneHotEncoder,
     RandomForestClassifier,
-    SMOTENCSampler,
-    SMOTENSampler,
-    SMOTESampler,
-    StackedEnsembleClassifier,
-    StackedEnsembleRegressor,
+    SklearnStackedEnsembleClassifier,
+    SklearnStackedEnsembleRegressor,
+    SMOTENCOversampler,
+    SMOTENOversampler,
+    SMOTEOversampler,
     StandardScaler,
     TargetImputer,
     TextFeaturizer,
@@ -79,6 +79,12 @@ def _get_preprocessing_components(
     if len(all_null_cols) > 0:
         pp_components.append(DropNullColumns)
 
+    index_and_unknown_columns = list(
+        X.ww.select(["index", "unknown"], return_schema=True).columns
+    )
+    if len(index_and_unknown_columns) > 0:
+        pp_components.append(DropColumns)
+
     email_columns = list(X.ww.select("EmailAddress", return_schema=True).columns)
     if len(email_columns) > 0:
         pp_components.append(EmailFeaturizer)
@@ -106,12 +112,6 @@ def _get_preprocessing_components(
     ):
         pp_components.append(Imputer)
 
-    index_and_unknown_columns = list(
-        X.ww.select(["index", "unknown"], return_schema=True).columns
-    )
-    if len(index_and_unknown_columns) > 0:
-        pp_components.append(DropColumns)
-
     datetime_cols = list(X.ww.select(["Datetime"], return_schema=True).columns)
 
     add_datetime_featurizer = len(datetime_cols) > 0
@@ -136,9 +136,9 @@ def _get_preprocessing_components(
 
     sampler_components = {
         "Undersampler": Undersampler,
-        "SMOTE Oversampler": SMOTESampler,
-        "SMOTENC Oversampler": SMOTENCSampler,
-        "SMOTEN Oversampler": SMOTENSampler,
+        "SMOTE Oversampler": SMOTEOversampler,
+        "SMOTENC Oversampler": SMOTENCOversampler,
+        "SMOTEN Oversampler": SMOTENOversampler,
     }
     if sampler_name is not None:
         try:
@@ -181,7 +181,7 @@ def make_pipeline(
     problem_type,
     parameters=None,
     sampler_name=None,
-    extra_components=[],
+    extra_components=None,
 ):
     """Given input data, target data, an estimator class and the problem type,
          generates a pipeline class with a preprocessing chain which was recommended based on the inputs.
@@ -196,7 +196,7 @@ def make_pipeline(
              An empty dictionary or None implies using all default values for component parameters.
          sampler_name (str): The name of the sampler component to add to the pipeline. Only used in classification problems.
              Defaults to None
-         extra_components (list(ComponentBase)): list of extra components to be added after preprocessing components.
+         extra_components (list(ComponentBase)): List of extra components to be added after preprocessing components. Defaults to None.
 
      Returns:
          PipelineBase object: PipelineBase instance with dynamically generated preprocessing components and specified estimator
@@ -215,7 +215,7 @@ def make_pipeline(
     preprocessing_components = _get_preprocessing_components(
         X, y, problem_type, estimator, sampler_name
     )
-
+    extra_components = extra_components or []
     complete_component_list = preprocessing_components + extra_components + [estimator]
     component_graph = PipelineBase._make_component_dict_from_component_list(
         complete_component_list
@@ -274,33 +274,33 @@ def _make_stacked_ensemble_pipeline(
     parameters = {}
     if is_classification(problem_type):
         parameters = {
-            "Stacked Ensemble Classifier": {
+            "Sklearn Stacked Ensemble Classifier": {
                 "input_pipelines": input_pipelines,
                 "n_jobs": n_jobs,
             }
         }
-        estimator = StackedEnsembleClassifier
+        estimator = SklearnStackedEnsembleClassifier
     else:
         parameters = {
-            "Stacked Ensemble Regressor": {
+            "Sklearn Stacked Ensemble Regressor": {
                 "input_pipelines": input_pipelines,
                 "n_jobs": n_jobs,
             }
         }
-        estimator = StackedEnsembleRegressor
+        estimator = SklearnStackedEnsembleRegressor
 
     pipeline_class, pipeline_name = {
         ProblemTypes.BINARY: (
             BinaryClassificationPipeline,
-            "Stacked Ensemble Classification Pipeline",
+            "Sklearn Stacked Ensemble Classification Pipeline",
         ),
         ProblemTypes.MULTICLASS: (
             MulticlassClassificationPipeline,
-            "Stacked Ensemble Classification Pipeline",
+            "Sklearn Stacked Ensemble Classification Pipeline",
         ),
         ProblemTypes.REGRESSION: (
             RegressionPipeline,
-            "Stacked Ensemble Regression Pipeline",
+            "Sklearn Stacked Ensemble Regression Pipeline",
         ),
     }[problem_type]
 
