@@ -52,9 +52,9 @@ from evalml.pipelines.components import (
     SelectByType,
     SelectColumns,
     SimpleImputer,
-    SMOTENCSampler,
-    SMOTENSampler,
-    SMOTESampler,
+    SMOTENCOversampler,
+    SMOTENOversampler,
+    SMOTEOversampler,
     StandardScaler,
     SVMClassifier,
     SVMRegressor,
@@ -67,8 +67,8 @@ from evalml.pipelines.components import (
     XGBoostRegressor,
 )
 from evalml.pipelines.components.ensemble import (
-    StackedEnsembleClassifier,
-    StackedEnsembleRegressor,
+    SklearnStackedEnsembleClassifier,
+    SklearnStackedEnsembleRegressor,
 )
 from evalml.pipelines.components.transformers.preprocessing.log_transformer import (
     LogTransformer,
@@ -291,7 +291,7 @@ def test_describe_component():
         },
     }
     try:
-        smote = SMOTESampler()
+        smote = SMOTEOversampler()
         assert smote.describe(return_dict=True) == {
             "name": "SMOTE Oversampler",
             "parameters": {
@@ -301,7 +301,7 @@ def test_describe_component():
                 "n_jobs": -1,
             },
         }
-        smote = SMOTENCSampler()
+        smote = SMOTENCOversampler()
         assert smote.describe(return_dict=True) == {
             "name": "SMOTENC Oversampler",
             "parameters": {
@@ -311,7 +311,7 @@ def test_describe_component():
                 "n_jobs": -1,
             },
         }
-        smote = SMOTENSampler()
+        smote = SMOTENOversampler()
         assert smote.describe(return_dict=True) == {
             "name": "SMOTEN Oversampler",
             "parameters": {
@@ -742,13 +742,13 @@ def test_component_parameters_init(
         try:
             component = component_class()
         except EnsembleMissingPipelinesError:
-            if component_class == StackedEnsembleClassifier:
+            if component_class == SklearnStackedEnsembleClassifier:
                 component = component_class(
                     input_pipelines=[
                         logistic_regression_binary_pipeline_class(parameters={})
                     ]
                 )
-            elif component_class == StackedEnsembleRegressor:
+            elif component_class == SklearnStackedEnsembleRegressor:
                 component = component_class(
                     input_pipelines=[linear_regression_pipeline_class(parameters={})]
                 )
@@ -868,12 +868,11 @@ def test_transformer_transform_output_type(X_y_binary):
             component.fit(X, y=y)
             transform_output = component.transform(X, y=y)
 
-            if isinstance(component, TargetImputer):
+            if isinstance(component, TargetImputer) or isinstance(
+                component, BaseSampler
+            ):
                 assert isinstance(transform_output[0], pd.DataFrame)
                 assert isinstance(transform_output[1], pd.Series)
-            elif "sampler" in component.name:
-                assert isinstance(transform_output[0], pd.DataFrame)
-                assert transform_output[1] is None
             else:
                 assert isinstance(transform_output, pd.DataFrame)
 
@@ -893,12 +892,12 @@ def test_transformer_transform_output_type(X_y_binary):
                 # We just want to check that DelayedFeaturesTransformer outputs a DataFrame
                 # The dataframe shape and index are checked in test_delayed_features_transformer.py
                 continue
-            elif isinstance(component, TargetImputer):
+            elif isinstance(component, TargetImputer) or isinstance(
+                component, BaseSampler
+            ):
                 assert transform_output[0].shape == X.shape
                 assert transform_output[1].shape[0] == X.shape[0]
                 assert len(transform_output[1].shape) == 1
-            elif "sampler" in component.name:
-                assert transform_output[0].shape == X.shape
             else:
                 assert transform_output.shape == X.shape
                 assert list(transform_output.columns) == list(X_cols_expected)
@@ -926,7 +925,7 @@ def test_transformer_transform_output_type(X_y_binary):
                 assert transform_output[0].shape == X.shape
                 assert transform_output[1].shape[0] == X.shape[0]
                 assert len(transform_output[1].shape) == 1
-            elif "sampler" in component.name:
+            elif isinstance(component, BaseSampler):
                 assert transform_output[0].shape == X.shape
                 assert transform_output[1].shape[0] == X.shape[0]
             else:
@@ -939,7 +938,8 @@ def test_transformer_transform_output_type(X_y_binary):
     [
         cls
         for cls in all_components()
-        if cls not in [StackedEnsembleRegressor, StackedEnsembleClassifier]
+        if cls
+        not in [SklearnStackedEnsembleRegressor, SklearnStackedEnsembleClassifier]
     ],
 )
 def test_default_parameters(cls):
@@ -953,7 +953,8 @@ def test_default_parameters(cls):
     [
         cls
         for cls in all_components()
-        if cls not in [StackedEnsembleRegressor, StackedEnsembleClassifier]
+        if cls
+        not in [SklearnStackedEnsembleRegressor, SklearnStackedEnsembleClassifier]
     ],
 )
 def test_default_parameters_raise_no_warnings(cls):
@@ -972,7 +973,7 @@ def test_estimator_check_for_fit(X_y_binary):
             return self
 
         def predict(self, X):
-            series = pd.Series()
+            series = pd.Series(dtype="string")
             series.ww.init()
             return series
 
@@ -1134,8 +1135,8 @@ def test_all_estimators_check_fit(
         for estimator in _all_estimators()
         if estimator
         not in [
-            StackedEnsembleClassifier,
-            StackedEnsembleRegressor,
+            SklearnStackedEnsembleClassifier,
+            SklearnStackedEnsembleRegressor,
             TimeSeriesBaselineEstimator,
         ]
     ] + [test_estimator_needs_fitting_false]
@@ -1224,7 +1225,7 @@ def test_serialization(X_y_binary, ts_data, tmpdir, helper_functions):
                 component_class
             )
         except EnsembleMissingPipelinesError:
-            if component_class == StackedEnsembleClassifier:
+            if component_class == SklearnStackedEnsembleClassifier:
                 component = component_class(
                     input_pipelines=[
                         BinaryClassificationPipeline(
@@ -1233,7 +1234,7 @@ def test_serialization(X_y_binary, ts_data, tmpdir, helper_functions):
                         )
                     ]
                 )
-            elif component_class == StackedEnsembleRegressor:
+            elif component_class == SklearnStackedEnsembleRegressor:
                 component = component_class(
                     input_pipelines=[
                         RegressionPipeline(
@@ -1260,8 +1261,8 @@ def test_serialization(X_y_binary, ts_data, tmpdir, helper_functions):
                 return_dict=True
             )
             if issubclass(component_class, Estimator) and not (
-                isinstance(component, StackedEnsembleClassifier)
-                or isinstance(component, StackedEnsembleRegressor)
+                isinstance(component, SklearnStackedEnsembleClassifier)
+                or isinstance(component, SklearnStackedEnsembleRegressor)
             ):
                 assert (
                     component.feature_importance == loaded_component.feature_importance
@@ -1296,13 +1297,13 @@ def test_estimators_accept_all_kwargs(
     try:
         estimator = estimator_class()
     except EnsembleMissingPipelinesError:
-        if estimator_class == StackedEnsembleClassifier:
+        if estimator_class == SklearnStackedEnsembleClassifier:
             estimator = estimator_class(
                 input_pipelines=[
                     logistic_regression_binary_pipeline_class(parameters={})
                 ]
             )
-        elif estimator_class == StackedEnsembleRegressor:
+        elif estimator_class == SklearnStackedEnsembleRegressor:
             estimator = estimator_class(
                 input_pipelines=[linear_regression_pipeline_class(parameters={})]
             )
@@ -1395,11 +1396,11 @@ def test_component_equality_all_components(
     logistic_regression_binary_pipeline_class,
     linear_regression_pipeline_class,
 ):
-    if component_class == StackedEnsembleClassifier:
+    if component_class == SklearnStackedEnsembleClassifier:
         component = component_class(
             input_pipelines=[logistic_regression_binary_pipeline_class(parameters={})]
         )
-    elif component_class == StackedEnsembleRegressor:
+    elif component_class == SklearnStackedEnsembleRegressor:
         component = component_class(
             input_pipelines=[linear_regression_pipeline_class(parameters={})]
         )
@@ -1459,13 +1460,13 @@ def test_component_str(
     try:
         component = component_class()
     except EnsembleMissingPipelinesError:
-        if component_class == StackedEnsembleClassifier:
+        if component_class == SklearnStackedEnsembleClassifier:
             component = component_class(
                 input_pipelines=[
                     logistic_regression_binary_pipeline_class(parameters={})
                 ]
             )
-        elif component_class == StackedEnsembleRegressor:
+        elif component_class == SklearnStackedEnsembleRegressor:
             component = component_class(
                 input_pipelines=[linear_regression_pipeline_class(parameters={})]
             )
@@ -1562,7 +1563,6 @@ def test_generate_code_custom(test_classes):
 def test_transformer_fit_and_transform_respect_custom_indices(
     use_custom_index, transformer_class, X_y_binary
 ):
-
     check_names = True
     if transformer_class == DFSTransformer:
         check_names = False
@@ -1594,10 +1594,12 @@ def test_transformer_fit_and_transform_respect_custom_indices(
     pd.testing.assert_index_equal(X.index, X_original_index)
     pd.testing.assert_index_equal(y.index, y_original_index)
 
-    if "sampler" in transformer.name:
-        X_t, y_t = transformer.transform(X, y)
-        assert y_t is None
-    elif transformer_class in [TargetImputer, LogTransformer]:
+    if isinstance(transformer, BaseSampler):
+        return
+    elif transformer_class in [
+        TargetImputer,
+        LogTransformer,
+    ]:
         X_t, y_t = transformer.transform(X, y)
         pd.testing.assert_index_equal(
             y_t.index, y_original_index, check_names=check_names
@@ -1623,13 +1625,13 @@ def test_estimator_fit_respects_custom_indices(
     helper_functions,
 ):
 
-    if estimator_class == StackedEnsembleRegressor:
+    if estimator_class == SklearnStackedEnsembleRegressor:
         input_pipelines = [
             helper_functions.safe_init_pipeline_with_njobs_1(
                 linear_regression_pipeline_class
             )
         ]
-    elif estimator_class == StackedEnsembleClassifier:
+    elif estimator_class == SklearnStackedEnsembleClassifier:
         input_pipelines = [
             helper_functions.safe_init_pipeline_with_njobs_1(
                 logistic_regression_binary_pipeline_class
