@@ -199,10 +199,7 @@ def test_estimator_predict_output_type(X_y_binary, helper_functions):
             predict_output = component.predict(X)
             assert isinstance(predict_output, pd.Series)
             assert len(predict_output) == len(y)
-            if component_class.name == "ARIMA Regressor":
-                assert predict_output.name == "predicted_mean"
-            else:
-                assert predict_output.name is None
+            assert predict_output.name is None
 
             if not (
                 (ProblemTypes.BINARY in component_class.supported_problem_types)
