@@ -12,6 +12,7 @@ from sklearn import datasets
 from skopt.space import Integer, Real
 
 from evalml.model_family import ModelFamily
+from evalml.objectives import BinaryClassificationObjective
 from evalml.objectives.utils import (
     get_core_objectives,
     get_non_core_objectives,
@@ -29,10 +30,10 @@ from evalml.pipelines.components import (
     DecisionTreeRegressor,
     Estimator,
     LogisticRegressionClassifier,
-    StackedEnsembleClassifier,
-    StackedEnsembleRegressor,
+    SklearnStackedEnsembleClassifier,
+    SklearnStackedEnsembleRegressor,
 )
-from evalml.pipelines.components.ensemble.stacked_ensemble_base import (
+from evalml.pipelines.components.ensemble.sklearn_stacked_ensemble_base import (
     _nonstackable_model_families,
 )
 from evalml.pipelines.components.utils import _all_estimators
@@ -122,8 +123,8 @@ def all_pipeline_classes():
     for estimator in [
         estimator
         for estimator in _all_estimators()
-        if estimator != StackedEnsembleClassifier
-        and estimator != StackedEnsembleRegressor
+        if estimator != SklearnStackedEnsembleClassifier
+        and estimator != SklearnStackedEnsembleRegressor
     ]:
         for problem_type in estimator.supported_problem_types:
             all_possible_pipeline_classes.append(
@@ -648,7 +649,9 @@ def linear_regression_pipeline_class():
 @pytest.fixture
 def dummy_stacked_ensemble_binary_estimator(logistic_regression_binary_pipeline_class):
     p1 = logistic_regression_binary_pipeline_class({})
-    ensemble_estimator = StackedEnsembleClassifier(input_pipelines=[p1], random_seed=0)
+    ensemble_estimator = SklearnStackedEnsembleClassifier(
+        input_pipelines=[p1], random_seed=0
+    )
     return ensemble_estimator
 
 
@@ -657,14 +660,18 @@ def dummy_stacked_ensemble_multiclass_estimator(
     logistic_regression_multiclass_pipeline_class,
 ):
     p1 = logistic_regression_multiclass_pipeline_class({})
-    ensemble_estimator = StackedEnsembleClassifier(input_pipelines=[p1], random_seed=0)
+    ensemble_estimator = SklearnStackedEnsembleClassifier(
+        input_pipelines=[p1], random_seed=0
+    )
     return ensemble_estimator
 
 
 @pytest.fixture
 def dummy_stacked_ensemble_regressor_estimator(linear_regression_pipeline_class):
     p1 = linear_regression_pipeline_class({})
-    ensemble_estimator = StackedEnsembleRegressor(input_pipelines=[p1], random_seed=0)
+    ensemble_estimator = SklearnStackedEnsembleRegressor(
+        input_pipelines=[p1], random_seed=0
+    )
     return ensemble_estimator
 
 
@@ -1315,3 +1322,21 @@ def df_with_url_and_email():
         }
     )
     return X
+
+
+def CustomClassificationObjectiveRanges(ranges):
+    class CustomClassificationObjectiveRanges(BinaryClassificationObjective):
+        """Accuracy score for binary and multiclass classification."""
+
+        name = "Classification Accuracy"
+        greater_is_better = True
+        score_needs_proba = False
+        perfect_score = 1.0
+        is_bounded_like_percentage = False
+        expected_range = ranges
+        problem_types = [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]
+
+        def objective_function(self, y_true, y_predicted, X=None):
+            """Not implementing since mocked in our tests."""
+
+    return CustomClassificationObjectiveRanges()
