@@ -426,8 +426,8 @@ class PipelineWithCustomComponent(BinaryClassificationPipeline):
         )
 
 
-class StackedEnsemblePipeline(BinaryClassificationPipeline):
-    component_graph = ["Stacked Ensemble Classifier"]
+class SklearnStackedEnsemblePipeline(BinaryClassificationPipeline):
+    component_graph = ["Sklearn Stacked Ensemble Classifier"]
 
     def __init__(self, parameters, random_seed=0):
         super().__init__(
@@ -442,7 +442,7 @@ pipelines_that_do_not_support_fast_permutation_importance = [
     PipelineWithDFS,
     PipelineWithCustomComponent,
     EnsembleDag,
-    StackedEnsemblePipeline,
+    SklearnStackedEnsemblePipeline,
 ]
 
 
@@ -450,7 +450,11 @@ pipelines_that_do_not_support_fast_permutation_importance = [
     "pipeline_class", pipelines_that_do_not_support_fast_permutation_importance
 )
 def test_supports_fast_permutation_importance(pipeline_class):
-    params = {"Stacked Ensemble Classifier": {"input_pipelines": [PipelineWithDFS({})]}}
+    params = {
+        "Sklearn Stacked Ensemble Classifier": {
+            "input_pipelines": [PipelineWithDFS({})]
+        }
+    }
     assert not pipeline_class(params)._supports_fast_permutation_importance
 
 
@@ -592,31 +596,6 @@ def test_get_permutation_importance_correlated_features(
     assert correlated_importance_val > not_correlated_importance_val
 
 
-def test_undersampler(X_y_binary):
-    """Smoke test to enable hotfix for 0.24.0.  Prior to the 0.24.0 hotfix, this test will
-    generate a ValueError within calculate_permutation_importance.
-
-    TODO: Remove with github issue #2273
-    """
-    X, y = X_y_binary
-    X = pd.DataFrame(X)
-    y = pd.Series(y)
-    pipeline = BinaryClassificationPipeline(
-        component_graph={
-            "Undersampler": ["Undersampler", "X", "y"],
-            "Elastic Net Classifier": [
-                "Elastic Net Classifier",
-                "Undersampler.x",
-                "Undersampler.y",
-            ],
-        }
-    )
-    pipeline.fit(X=X, y=y)
-    pipeline.predict(X)
-    test = calculate_permutation_importance(pipeline, X, y, objective="Log Loss Binary")
-    assert test is not None
-
-
 def test_permutation_importance_oversampler(fraud_100):
     pytest.importorskip(
         "imblearn.over_sampling",
@@ -675,7 +654,11 @@ def test_get_permutation_importance_one_column_pipeline_does_not_support_fast(
     X_y_binary, pipeline_class
 ):
     X, y = X_y_binary
-    params = {"Stacked Ensemble Classifier": {"input_pipelines": [PipelineWithDFS({})]}}
+    params = {
+        "Sklearn Stacked Ensemble Classifier": {
+            "input_pipelines": [PipelineWithDFS({})]
+        }
+    }
     assert not pipeline_class(params)._supports_fast_permutation_importance
     with pytest.raises(
         ValueError,
