@@ -1,3 +1,4 @@
+import re
 import warnings
 from datetime import datetime, timedelta
 from unittest.mock import patch
@@ -12,7 +13,11 @@ from pandas.testing import (
 )
 from woodwork.logical_types import Double, Integer
 
-from evalml.exceptions import MissingComponentError, ParameterNotUsedWarning
+from evalml.exceptions import (
+    MethodPropertyNotFoundError,
+    MissingComponentError,
+    ParameterNotUsedWarning,
+)
 from evalml.pipelines import ComponentGraph
 from evalml.pipelines.components import (
     DateTimeFeaturizer,
@@ -139,6 +144,24 @@ def test_init_str_components():
     assert comp_graph.compute_order == expected_order
 
 
+def test_init_instantiated():
+    graph = {
+        "Imputer": [
+            Imputer(numeric_impute_strategy="constant", numeric_fill_value=0),
+            "X",
+            "y",
+        ]
+    }
+    component_graph = ComponentGraph(graph)
+    component_graph.instantiate(
+        {"Imputer": {"numeric_fill_value": 10, "categorical_fill_value": "Fill"}}
+    )
+    cg_imputer = component_graph.get_component("Imputer")
+    assert graph["Imputer"][0] == cg_imputer
+    assert cg_imputer.parameters["numeric_fill_value"] == 0
+    assert cg_imputer.parameters["categorical_fill_value"] is None
+
+
 def test_invalid_init():
     invalid_graph = {"Imputer": [Imputer, "X", "y"], "OHE": OneHotEncoder}
     with pytest.raises(
@@ -148,7 +171,7 @@ def test_invalid_init():
 
     graph = {
         "Imputer": [
-            Imputer(numeric_impute_strategy="constant", numeric_fill_value=0),
+            None,
             "X",
             "y",
         ]
@@ -406,19 +429,20 @@ def test_get_last_component(example_graph):
 
 @patch("evalml.pipelines.components.Transformer.fit_transform")
 @patch("evalml.pipelines.components.Estimator.fit")
-@patch("evalml.pipelines.components.Estimator.predict")
+@patch("evalml.pipelines.components.Estimator.predict_proba")
 def test_fit_component_graph(
-    mock_predict, mock_fit, mock_fit_transform, example_graph, X_y_binary
+    mock_predict_proba, mock_fit, mock_fit_transform, example_graph, X_y_binary
 ):
     X, y = X_y_binary
     mock_fit_transform.return_value = pd.DataFrame(X)
-    mock_predict.return_value = pd.Series(y)
+    mock_predict_proba.return_value = pd.DataFrame(y)
+    mock_predict_proba.return_value.ww.init()
     component_graph = ComponentGraph(example_graph).instantiate({})
     component_graph.fit(X, y)
 
     assert mock_fit_transform.call_count == 3
     assert mock_fit.call_count == 3
-    assert mock_predict.call_count == 2
+    assert mock_predict_proba.call_count == 2
 
 
 @patch("evalml.pipelines.components.Imputer.fit_transform")
@@ -447,9 +471,9 @@ def test_fit_correct_inputs(
 
 @patch("evalml.pipelines.components.Transformer.fit_transform")
 @patch("evalml.pipelines.components.Estimator.fit")
-@patch("evalml.pipelines.components.Estimator.predict")
+@patch("evalml.pipelines.components.Estimator.predict_proba")
 def test_component_graph_fit_features(
-    mock_predict, mock_fit, mock_fit_transform, example_graph, X_y_binary
+    mock_predict_proba, mock_fit, mock_fit_transform, example_graph, X_y_binary
 ):
     X, y = X_y_binary
     component_graph = ComponentGraph(example_graph)
@@ -458,36 +482,111 @@ def test_component_graph_fit_features(
     mock_X_t = pd.DataFrame(np.ones(pd.DataFrame(X).shape))
     mock_fit_transform.return_value = mock_X_t
     mock_fit.return_value = Estimator
-    mock_predict.return_value = pd.Series(y)
+    mock_predict_proba.return_value = pd.DataFrame(y)
+    mock_predict_proba.return_value.ww.init()
 
     component_graph.fit_features(X, y)
 
     assert mock_fit_transform.call_count == 3
     assert mock_fit.call_count == 2
-    assert mock_predict.call_count == 2
+    assert mock_predict_proba.call_count == 2
 
 
 @patch("evalml.pipelines.components.Estimator.fit")
+@patch("evalml.pipelines.components.Estimator.predict_proba")
 @patch("evalml.pipelines.components.Estimator.predict")
-def test_predict(mock_predict, mock_fit, example_graph, X_y_binary):
+def test_predict(mock_predict, mock_predict_proba, mock_fit, example_graph, X_y_binary):
     X, y = X_y_binary
+    mock_predict_proba.return_value = pd.DataFrame(y)
+    mock_predict_proba.return_value.ww.init()
     mock_predict.return_value = pd.Series(y)
     component_graph = ComponentGraph(example_graph).instantiate({})
     component_graph.fit(X, y)
 
     component_graph.predict(X)
     assert (
-        mock_predict.call_count == 5
-    )  # Called twice when fitting pipeline, thrice when predicting
+        mock_predict_proba.call_count == 4
+    )  # Called twice when fitting pipeline, twice when predicting
+    assert mock_predict.call_count == 1  # Called once during predict
+
     assert mock_fit.call_count == 3  # Only called during fit, not predict
 
 
 @patch("evalml.pipelines.components.Estimator.fit")
+@patch("evalml.pipelines.components.Estimator.predict_proba")
 @patch("evalml.pipelines.components.Estimator.predict")
-def test_predict_repeat_estimator(mock_predict, mock_fit, X_y_binary):
-    X, y = X_y_binary
+def test_predict_multiclass(
+    mock_predict, mock_predict_proba, mock_fit, example_graph, X_y_multi
+):
+    X, y = X_y_multi
+    mock_predict_proba.return_value = pd.DataFrame(
+        {
+            0: np.full(X.shape[0], 0.33),
+            1: np.full(X.shape[0], 0.33),
+            2: np.full(X.shape[0], 0.33),
+        }
+    )
+    mock_predict_proba.return_value.ww.init()
     mock_predict.return_value = pd.Series(y)
+    component_graph = ComponentGraph(example_graph).instantiate({})
+    component_graph.fit(X, y)
+    final_estimator_input = component_graph.compute_final_component_features(X, y)
+    assert final_estimator_input.columns.to_list() == [
+        "Col 0 Random Forest.x",
+        "Col 1 Random Forest.x",
+        "Col 2 Random Forest.x",
+        "Col 0 Elastic Net.x",
+        "Col 1 Elastic Net.x",
+        "Col 2 Elastic Net.x",
+    ]
+    for col in final_estimator_input:
+        assert np.array_equal(
+            final_estimator_input[col].to_numpy(), np.full(X.shape[0], 0.33)
+        )
+    component_graph.predict(X)
+    assert (
+        mock_predict_proba.call_count == 6
+    )  # Called twice when fitting pipeline, twice to compute final features, and twice when predicting
+    assert mock_predict.call_count == 1  # Called once during predict
+    assert mock_fit.call_count == 3  # Only called during fit, not predict
 
+
+@patch("evalml.pipelines.components.Estimator.fit")
+@patch("evalml.pipelines.components.Estimator.predict_proba")
+@patch("evalml.pipelines.components.Estimator.predict")
+def test_predict_regression(
+    mock_predict, mock_predict_proba, mock_fit, example_regression_graph, X_y_multi
+):
+    X, y = X_y_multi
+    mock_predict.return_value = pd.Series(y)
+    mock_predict_proba.side_effect = MethodPropertyNotFoundError
+    component_graph = ComponentGraph(example_regression_graph).instantiate({})
+    component_graph.fit(X, y)
+    final_estimator_input = component_graph.compute_final_component_features(X, y)
+    assert final_estimator_input.columns.to_list() == [
+        "Random Forest.x",
+        "Elastic Net.x",
+    ]
+    component_graph.predict(X)
+    assert (
+        mock_predict_proba.call_count == 6
+    )  # Called twice when fitting pipeline, twice to compute final features, and twice when predicting
+    assert (
+        mock_predict.call_count == 7
+    )  # Called because `predict_proba` does not exist for regresssions
+    assert mock_fit.call_count == 3  # Only called during fit, not predict
+
+
+@patch("evalml.pipelines.components.Estimator.fit")
+@patch("evalml.pipelines.components.Estimator.predict_proba")
+@patch("evalml.pipelines.components.Estimator.predict")
+def test_predict_repeat_estimator(
+    mock_predict, mock_predict_proba, mock_fit, X_y_binary
+):
+    X, y = X_y_binary
+    mock_predict_proba.return_value = pd.DataFrame(y)
+    mock_predict_proba.return_value.ww.init()
+    mock_predict.return_value = pd.Series(y)
     graph = {
         "Imputer": [Imputer, "X", "y"],
         "OneHot_RandomForest": [OneHotEncoder, "Imputer.x", "y"],
@@ -511,24 +610,39 @@ def test_predict_repeat_estimator(mock_predict, mock_fit, X_y_binary):
     )
 
     component_graph.predict(X)
-    assert mock_predict.call_count == 5
+    assert mock_predict_proba.call_count == 4
+    assert mock_predict.call_count == 1
     assert mock_fit.call_count == 3
 
 
 @patch("evalml.pipelines.components.Imputer.transform")
 @patch("evalml.pipelines.components.OneHotEncoder.transform")
-@patch("evalml.pipelines.components.RandomForestClassifier.predict")
-@patch("evalml.pipelines.components.ElasticNetClassifier.predict")
+@patch("evalml.pipelines.components.RandomForestClassifier.predict_proba")
+@patch("evalml.pipelines.components.ElasticNetClassifier.predict_proba")
 def test_compute_final_component_features(
-    mock_en_predict, mock_rf_predict, mock_ohe, mock_imputer, example_graph, X_y_binary
+    mock_en_predict_proba,
+    mock_rf_predict_proba,
+    mock_ohe,
+    mock_imputer,
+    example_graph,
+    X_y_binary,
 ):
     X, y = X_y_binary
     mock_imputer.return_value = pd.DataFrame(X)
     mock_ohe.return_value = pd.DataFrame(X)
-    mock_en_predict.return_value = pd.Series(np.ones(X.shape[0]))
-    mock_rf_predict.return_value = pd.Series(np.zeros(X.shape[0]))
+    mock_en_predict_proba.return_value = pd.DataFrame(
+        ({0: np.zeros(X.shape[0]), 1: np.ones(X.shape[0])})
+    )
+    mock_en_predict_proba.return_value.ww.init()
+    mock_rf_predict_proba.return_value = pd.DataFrame(
+        ({0: np.ones(X.shape[0]), 1: np.zeros(X.shape[0])})
+    )
+    mock_rf_predict_proba.return_value.ww.init()
     X_expected = pd.DataFrame(
-        {"Random Forest.x": np.zeros(X.shape[0]), "Elastic Net.x": np.ones(X.shape[0])}
+        {
+            "Col 1 Random Forest.x": np.zeros(X.shape[0]),
+            "Col 1 Elastic Net.x": np.ones(X.shape[0]),
+        }
     )
     component_graph = ComponentGraph(example_graph).instantiate({})
     component_graph.fit(X, y)
@@ -575,22 +689,11 @@ def test_predict_empty_graph(X_y_binary):
     component_graph.instantiate({})
 
     component_graph.fit(X, y)
-    X_t = component_graph.predict(X)
+    X_t = component_graph.transform(X, y)
     assert_frame_equal(X, X_t)
 
-
-@patch("evalml.pipelines.components.OneHotEncoder.fit_transform")
-@patch("evalml.pipelines.components.OneHotEncoder.transform")
-def test_predict_transformer_end(mock_fit_transform, mock_transform, X_y_binary):
-    X, y = X_y_binary
-    graph = {"Imputer": [Imputer, "X", "y"], "OHE": [OneHotEncoder, "Imputer.x", "y"]}
-    component_graph = ComponentGraph(graph).instantiate({})
-    mock_fit_transform.return_value = tuple((pd.DataFrame(X), pd.Series(y)))
-    mock_transform.return_value = tuple((pd.DataFrame(X), pd.Series(y)))
-
-    component_graph.fit(X, y)
-    output = component_graph.predict(X)
-    assert_frame_equal(pd.DataFrame(X), output)
+    X_pred = component_graph.predict(X)
+    assert_frame_equal(X, X_pred)
 
 
 def test_no_instantiate_before_fit(X_y_binary):
@@ -608,21 +711,14 @@ def test_no_instantiate_before_fit(X_y_binary):
         component_graph.fit(X, y)
 
 
-@patch("evalml.pipelines.components.Imputer.fit_transform")
-def test_multiple_y_parents(mock_fit_transform, X_y_binary):
-    X, y = X_y_binary
+def test_multiple_y_parents():
     graph = {
         "Imputer": [Imputer, "X", "y"],
         "TargetImputer": [Imputer, "Imputer.x", "y"],
         "Estimator": [RandomForestClassifier, "Imputer.x", "y", "TargetImputer.y"],
     }
-    component_graph = ComponentGraph(graph)
-    component_graph.instantiate({})
-    mock_fit_transform.return_value = tuple((pd.DataFrame(X), pd.Series(y)))
-    with pytest.raises(
-        ValueError, match="Cannot have multiple `y` parents for a single component"
-    ):
-        component_graph.fit(X, y)
+    with pytest.raises(ValueError, match="All components must have exactly one target"):
+        ComponentGraph(graph)
 
 
 def test_component_graph_order(example_graph):
@@ -673,12 +769,12 @@ def test_computation_input_custom_index(index, example_graph):
 @patch(f"{__name__}.TransformerB.transform")
 @patch(f"{__name__}.TransformerA.transform")
 def test_component_graph_evaluation_plumbing(
-    mock_transa,
-    mock_transb,
-    mock_transc,
-    mock_preda,
-    mock_predb,
-    mock_predc,
+    mock_transform_a,
+    mock_transform_b,
+    mock_transform_c,
+    mock_predict_a,
+    mock_predict_b,
+    mock_predict_c,
     dummy_components,
 ):
     (
@@ -689,18 +785,18 @@ def test_component_graph_evaluation_plumbing(
         EstimatorB,
         EstimatorC,
     ) = dummy_components
-    mock_transa.return_value = pd.DataFrame(
+    mock_transform_a.return_value = pd.DataFrame(
         {"feature trans": [1, 0, 0, 0, 0, 0], "feature a": np.ones(6)}
     )
-    mock_transb.return_value = pd.DataFrame({"feature b": np.ones(6) * 2})
-    mock_transc.return_value = pd.DataFrame({"feature c": np.ones(6) * 3})
-    mock_preda.return_value = pd.Series([0, 0, 0, 1, 0, 0])
-    mock_predb.return_value = pd.Series([0, 0, 0, 0, 1, 0])
-    mock_predc.return_value = pd.Series([0, 0, 0, 0, 0, 1])
+    mock_transform_b.return_value = pd.DataFrame({"feature b": np.ones(6) * 2})
+    mock_transform_c.return_value = pd.DataFrame({"feature c": np.ones(6) * 3})
+    mock_predict_a.return_value = pd.Series([0, 0, 0, 1, 0, 0])
+    mock_predict_b.return_value = pd.Series([0, 0, 0, 0, 1, 0])
+    mock_predict_c.return_value = pd.Series([0, 0, 0, 0, 0, 1])
     graph = {
         "transformer a": [TransformerA, "X", "y"],
         "transformer b": [TransformerB, "transformer a.x", "y"],
-        "transformer c": [TransformerC, "transformer a", "transformer b.x", "y"],
+        "transformer c": [TransformerC, "transformer a.x", "transformer b.x", "y"],
         "estimator a": [EstimatorA, "X", "y"],
         "estimator b": [EstimatorB, "transformer a.x", "y"],
         "estimator c": [
@@ -720,9 +816,9 @@ def test_component_graph_evaluation_plumbing(
     component_graph.fit(X, y)
     predict_out = component_graph.predict(X)
 
-    assert_frame_equal(mock_transa.call_args[0][0], X)
+    assert_frame_equal(mock_transform_a.call_args[0][0], X)
     assert_frame_equal(
-        mock_transb.call_args[0][0],
+        mock_transform_b.call_args[0][0],
         pd.DataFrame(
             {
                 "feature trans": pd.Series([1, 0, 0, 0, 0, 0], dtype="int64"),
@@ -732,7 +828,7 @@ def test_component_graph_evaluation_plumbing(
         ),
     )
     assert_frame_equal(
-        mock_transc.call_args[0][0],
+        mock_transform_c.call_args[0][0],
         pd.DataFrame(
             {
                 "feature trans": pd.Series([1, 0, 0, 0, 0, 0], dtype="int64"),
@@ -742,9 +838,9 @@ def test_component_graph_evaluation_plumbing(
             columns=["feature trans", "feature a", "feature b"],
         ),
     )
-    assert_frame_equal(mock_preda.call_args[0][0], X)
+    assert_frame_equal(mock_predict_a.call_args[0][0], X)
     assert_frame_equal(
-        mock_predb.call_args[0][0],
+        mock_predict_b.call_args[0][0],
         pd.DataFrame(
             {
                 "feature trans": pd.Series([1, 0, 0, 0, 0, 0], dtype="int64"),
@@ -754,7 +850,7 @@ def test_component_graph_evaluation_plumbing(
         ),
     )
     assert_frame_equal(
-        mock_predc.call_args[0][0],
+        mock_predict_c.call_args[0][0],
         pd.DataFrame(
             {
                 "feature trans": pd.Series([1, 0, 0, 0, 0, 0], dtype="int64"),
@@ -809,8 +905,8 @@ def test_input_feature_names(example_graph):
         "column_1_c",
     ]
     assert input_feature_names["Logistic Regression"] == [
-        "Random Forest.x",
-        "Elastic Net.x",
+        "Col 1 Random Forest.x",
+        "Col 1 Elastic Net.x",
     ]
 
 
@@ -877,8 +973,8 @@ def test_custom_input_feature_types(example_graph):
         "column_2_5",
     ]
     assert input_feature_names["Logistic Regression"] == [
-        "Random Forest.x",
-        "Elastic Net.x",
+        "Col 1 Random Forest.x",
+        "Col 1 Elastic Net.x",
     ]
 
 
@@ -1047,8 +1143,8 @@ def test_component_graph_dataset_with_different_types():
             )
         )
         assert input_feature_names["Logistic Regression"] == [
-            "Random Forest.x",
-            "Elastic Net.x",
+            "Col 1 Random Forest.x",
+            "Col 1 Elastic Net.x",
         ]
 
     check_feature_names(component_graph.input_feature_names)
@@ -1277,7 +1373,7 @@ def test_component_graph_types_merge():
     )
 
 
-def test_component_graph_sampler():
+def test_component_graph_get_inputs_with_sampler():
     graph = {
         "Imputer": [Imputer, "X", "y"],
         "OneHot": [OneHotEncoder, "Imputer.x", "y"],
@@ -1591,167 +1687,215 @@ class SubsetData(Transformer):
         return X_new, y_new
 
 
-component_graphs = [
-    (
-        ComponentGraph(
-            {
-                "Imputer": [Imputer, "X", "y"],
-                "Log": [LogTransform, "X", "y"],
-                "Random Forest": ["Random Forest Regressor", "Imputer.x", "Log.y"],
-            }
+@pytest.mark.parametrize(
+    "component_graph,answer_func",
+    [
+        (
+            ComponentGraph(
+                {
+                    "Imputer": [Imputer, "X", "y"],
+                    "Log": [LogTransform, "X", "y"],
+                    "Random Forest": ["Random Forest Regressor", "Imputer.x", "Log.y"],
+                }
+            ),
+            lambda y: infer_feature_types(np.exp(y)),
         ),
-        lambda y: infer_feature_types(np.exp(y)),
-    ),
-    (
-        ComponentGraph(
-            {
-                "Imputer": [Imputer, "X", "y"],
-                "Log": [LogTransform, "X", "y"],
-                "Double": [DoubleTransform, "X", "Log.y"],
-                "Random Forest": ["Random Forest Regressor", "Imputer.x", "Double.y"],
-            }
+        (
+            ComponentGraph(
+                {
+                    "Imputer": [Imputer, "X", "y"],
+                    "Log": [LogTransform, "X", "y"],
+                    "Double": [DoubleTransform, "X", "Log.y"],
+                    "Random Forest": [
+                        "Random Forest Regressor",
+                        "Imputer.x",
+                        "Double.y",
+                    ],
+                }
+            ),
+            lambda y: infer_feature_types(np.exp(y / 2)),
         ),
-        lambda y: infer_feature_types(np.exp(y / 2)),
-    ),
-    (
-        ComponentGraph(
-            {
-                "Imputer": [Imputer, "X", "y"],
-                "Log": [LogTransform, "Imputer.x", "y"],
-                "Double": [DoubleTransform, "Log.x", "Log.y"],
-                "Random Forest": ["Random Forest Regressor", "Double.x", "Double.y"],
-            }
+        (
+            ComponentGraph(
+                {
+                    "Imputer": [Imputer, "X", "y"],
+                    "Log": [LogTransform, "Imputer.x", "y"],
+                    "Double": [DoubleTransform, "Log.x", "Log.y"],
+                    "Random Forest": [
+                        "Random Forest Regressor",
+                        "Double.x",
+                        "Double.y",
+                    ],
+                }
+            ),
+            lambda y: infer_feature_types(np.exp(y / 2)),
         ),
-        lambda y: infer_feature_types(np.exp(y / 2)),
-    ),
-    (
-        ComponentGraph(
-            {
-                "Imputer": [Imputer, "X", "y"],
-                "OneHot": [OneHotEncoder, "Imputer.x", "y"],
-                "DateTime": [DateTimeFeaturizer, "OneHot.x", "y"],
-                "Log": [LogTransform, "X", "y"],
-                "Double": [DoubleTransform, "DateTime.x", "Log.y"],
-                "Random Forest": ["Random Forest Regressor", "DateTime.x", "Double.y"],
-            }
+        (
+            ComponentGraph(
+                {
+                    "Imputer": [Imputer, "X", "y"],
+                    "OneHot": [OneHotEncoder, "Imputer.x", "y"],
+                    "DateTime": [DateTimeFeaturizer, "OneHot.x", "y"],
+                    "Log": [LogTransform, "X", "y"],
+                    "Double": [DoubleTransform, "DateTime.x", "Log.y"],
+                    "Random Forest": [
+                        "Random Forest Regressor",
+                        "DateTime.x",
+                        "Double.y",
+                    ],
+                }
+            ),
+            lambda y: infer_feature_types(np.exp(y / 2)),
         ),
-        lambda y: infer_feature_types(np.exp(y / 2)),
-    ),
-    (
-        ComponentGraph(
-            {
-                "Imputer": [Imputer, "X", "y"],
-                "OneHot": [OneHotEncoder, "Imputer.x", "y"],
-                "DateTime": [DateTimeFeaturizer, "OneHot.x", "y"],
-                "Log": [LogTransform, "X", "y"],
-                "Double": [DoubleTransform, "X", "Log.y"],
-                "Double2": [DoubleTransform, "X", "Double.y"],
-                "Random Forest": ["Random Forest Regressor", "DateTime.x", "Double2.y"],
-            }
+        (
+            ComponentGraph(
+                {
+                    "Imputer": [Imputer, "X", "y"],
+                    "OneHot": [OneHotEncoder, "Imputer.x", "y"],
+                    "DateTime": [DateTimeFeaturizer, "OneHot.x", "y"],
+                    "Log": [LogTransform, "X", "y"],
+                    "Double": [DoubleTransform, "X", "Log.y"],
+                    "Double2": [DoubleTransform, "X", "Double.y"],
+                    "Random Forest": [
+                        "Random Forest Regressor",
+                        "DateTime.x",
+                        "Double2.y",
+                    ],
+                }
+            ),
+            lambda y: infer_feature_types(np.exp(y / 4)),
         ),
-        lambda y: infer_feature_types(np.exp(y / 4)),
-    ),
-    (
-        ComponentGraph(
-            {
-                "Imputer": ["Imputer", "X", "y"],
-                "Double": [DoubleTransform, "X", "y"],
-                "DateTime 1": ["DateTime Featurization Component", "Imputer.x", "y"],
-                "ET": ["Extra Trees Regressor", "DateTime 1.x", "Double.y"],
-                "Double 2": [DoubleTransform, "X", "y"],
-                "DateTime 2": ["DateTime Featurization Component", "Imputer.x", "y"],
-                "Double 3": [DoubleTransform, "X", "Double 2.y"],
-                "RandomForest": [
-                    "Random Forest Regressor",
-                    "DateTime 2.x",
-                    "Double 3.y",
-                ],
-                "DateTime 3": ["DateTime Featurization Component", "Imputer.x", "y"],
-                "Double 4": [DoubleTransform, "X", "y"],
-                "Catboost": ["Random Forest Regressor", "DateTime 3.x", "Double 4.y"],
-                "Logistic Regression": [
-                    "Linear Regressor",
-                    "Catboost.x",
-                    "RandomForest.x",
-                    "ET.x",
-                    "Double 3.y",
-                ],
-            }
+        (
+            ComponentGraph(
+                {
+                    "Imputer": ["Imputer", "X", "y"],
+                    "Double": [DoubleTransform, "X", "y"],
+                    "DateTime 1": [
+                        "DateTime Featurization Component",
+                        "Imputer.x",
+                        "y",
+                    ],
+                    "ET": ["Extra Trees Regressor", "DateTime 1.x", "Double.y"],
+                    "Double 2": [DoubleTransform, "X", "y"],
+                    "DateTime 2": [
+                        "DateTime Featurization Component",
+                        "Imputer.x",
+                        "y",
+                    ],
+                    "Double 3": [DoubleTransform, "X", "Double 2.y"],
+                    "RandomForest": [
+                        "Random Forest Regressor",
+                        "DateTime 2.x",
+                        "Double 3.y",
+                    ],
+                    "DateTime 3": [
+                        "DateTime Featurization Component",
+                        "Imputer.x",
+                        "y",
+                    ],
+                    "Double 4": [DoubleTransform, "X", "y"],
+                    "Catboost": [
+                        "Random Forest Regressor",
+                        "DateTime 3.x",
+                        "Double 4.y",
+                    ],
+                    "Logistic Regression": [
+                        "Linear Regressor",
+                        "Catboost.x",
+                        "RandomForest.x",
+                        "ET.x",
+                        "Double 3.y",
+                    ],
+                }
+            ),
+            lambda y: infer_feature_types(y / 4),
         ),
-        lambda y: infer_feature_types(y / 4),
-    ),
-    (
-        ComponentGraph(
-            {
-                "Imputer": [Imputer, "X", "y"],
-                "OneHot": [OneHotEncoder, "Imputer.x", "y"],
-                "DateTime": [DateTimeFeaturizer, "OneHot.x", "y"],
-                "Log": [LogTransform, "X", "y"],
-                "Double": [DoubleTransform, "X", "Log.y"],
-                "Double2": [DoubleTransform, "X", "Double.y"],
-                "Subset": [SubsetData, "DateTime.x", "Double2.y"],
-                "Random Forest": ["Random Forest Regressor", "Subset.x", "Subset.y"],
-            }
+        (
+            ComponentGraph(
+                {
+                    "Imputer": [Imputer, "X", "y"],
+                    "OneHot": [OneHotEncoder, "Imputer.x", "y"],
+                    "DateTime": [DateTimeFeaturizer, "OneHot.x", "y"],
+                    "Log": [LogTransform, "X", "y"],
+                    "Double": [DoubleTransform, "X", "Log.y"],
+                    "Double2": [DoubleTransform, "X", "Double.y"],
+                    "Subset": [SubsetData, "DateTime.x", "Double2.y"],
+                    "Random Forest": [
+                        "Random Forest Regressor",
+                        "Subset.x",
+                        "Subset.y",
+                    ],
+                }
+            ),
+            lambda y: infer_feature_types(np.exp(y / 4)),
         ),
-        lambda y: infer_feature_types(np.exp(y / 4)),
-    ),
-    (
-        ComponentGraph(
-            {
-                "Imputer": [Imputer, "X", "y"],
-                "Random Forest": ["Random Forest Regressor", "Imputer.x", "y"],
-            }
+        (
+            ComponentGraph(
+                {
+                    "Imputer": [Imputer, "X", "y"],
+                    "Random Forest": ["Random Forest Regressor", "Imputer.x", "y"],
+                }
+            ),
+            lambda y: y,
         ),
-        lambda y: y,
-    ),
-    (
-        ComponentGraph(
-            {
-                "Imputer": [Imputer, "X", "y"],
-                "DateTime": [DateTimeFeaturizer, "Imputer.x", "y"],
-                "OneHot": [OneHotEncoder, "DateTime.x", "y"],
-                "Random Forest": ["Random Forest Regressor", "OneHot.x", "y"],
-            }
+        (
+            ComponentGraph(
+                {
+                    "Imputer": [Imputer, "X", "y"],
+                    "DateTime": [DateTimeFeaturizer, "Imputer.x", "y"],
+                    "OneHot": [OneHotEncoder, "DateTime.x", "y"],
+                    "Random Forest": ["Random Forest Regressor", "OneHot.x", "y"],
+                }
+            ),
+            lambda y: y,
         ),
-        lambda y: y,
-    ),
-    (
-        ComponentGraph({"Random Forest": ["Random Forest Regressor", "X", "y"]}),
-        lambda y: y,
-    ),
-    (
-        ComponentGraph(
-            {
-                "Imputer": ["Imputer", "X", "y"],
-                "Double": [DoubleTransform, "X", "y"],
-                "DateTime 1": ["DateTime Featurization Component", "Imputer.x", "y"],
-                "ET": ["Extra Trees Regressor", "DateTime 1.x", "Double.y"],
-                "Double 2": [DoubleTransform, "X", "y"],
-                "DateTime 2": ["DateTime Featurization Component", "Imputer.x", "y"],
-                "Double 3": [DoubleTransform, "X", "Double 2.y"],
-                "RandomForest": [
-                    "Random Forest Regressor",
-                    "DateTime 2.x",
-                    "Double 3.y",
-                ],
-                "DateTime 3": ["DateTime Featurization Component", "Imputer.x", "y"],
-                "Double 4": [DoubleTransform, "X", "y"],
-                "Linear": ["Linear Regressor", "DateTime 3.x", "Double 4.y"],
-                "Logistic Regression": [
-                    "Linear Regressor",
-                    "Linear.x",
-                    "RandomForest.x",
-                    "ET.x",
-                    "y",
-                ],
-            }
+        (
+            ComponentGraph({"Random Forest": ["Random Forest Regressor", "X", "y"]}),
+            lambda y: y,
         ),
-        lambda y: y,
-    ),
-]
-
-
-@pytest.mark.parametrize("component_graph,answer_func", component_graphs)
+        (
+            ComponentGraph(
+                {
+                    "Imputer": ["Imputer", "X", "y"],
+                    "Double": [DoubleTransform, "X", "y"],
+                    "DateTime 1": [
+                        "DateTime Featurization Component",
+                        "Imputer.x",
+                        "y",
+                    ],
+                    "ET": ["Extra Trees Regressor", "DateTime 1.x", "Double.y"],
+                    "Double 2": [DoubleTransform, "X", "y"],
+                    "DateTime 2": [
+                        "DateTime Featurization Component",
+                        "Imputer.x",
+                        "y",
+                    ],
+                    "Double 3": [DoubleTransform, "X", "Double 2.y"],
+                    "RandomForest": [
+                        "Random Forest Regressor",
+                        "DateTime 2.x",
+                        "Double 3.y",
+                    ],
+                    "DateTime 3": [
+                        "DateTime Featurization Component",
+                        "Imputer.x",
+                        "y",
+                    ],
+                    "Double 4": [DoubleTransform, "X", "y"],
+                    "Linear": ["Linear Regressor", "DateTime 3.x", "Double 4.y"],
+                    "Logistic Regression": [
+                        "Linear Regressor",
+                        "Linear.x",
+                        "RandomForest.x",
+                        "ET.x",
+                        "y",
+                    ],
+                }
+            ),
+            lambda y: y,
+        ),
+    ],
+)
 def test_component_graph_inverse_transform(
     component_graph, answer_func, X_y_regression
 ):
@@ -1874,7 +2018,9 @@ def test_component_graph_with_X_y_inputs_y(mock_fit, mock_fit_transform):
 
 def test_component_graph_does_not_define_all_edges():
     # Graph does not define an X edge
-    with pytest.raises(ValueError, match="All edges must be specified"):
+    with pytest.raises(
+        ValueError, match="All components must have at least one input feature"
+    ):
         ComponentGraph(
             {
                 "Imputer": [Imputer, "y"],  # offending line
@@ -1888,7 +2034,7 @@ def test_component_graph_does_not_define_all_edges():
             }
         )
     # Graph does not define a y edge
-    with pytest.raises(ValueError, match="All edges must be specified"):
+    with pytest.raises(ValueError, match="All components must have exactly one target"):
         ComponentGraph(
             {
                 "Imputer": [Imputer, "X"],  # offending line
@@ -1902,7 +2048,9 @@ def test_component_graph_does_not_define_all_edges():
             }
         )
     # Graph does not define X and y edges
-    with pytest.raises(ValueError, match="All edges must be specified"):
+    with pytest.raises(
+        ValueError, match="All components must have at least one input feature"
+    ):
         ComponentGraph(
             {
                 "Imputer": [Imputer],  # offending line
@@ -1917,9 +2065,35 @@ def test_component_graph_does_not_define_all_edges():
         )
 
 
+def test_component_graph_defines_edges_with_bad_syntax():
+    # Graph does not define an X edge
+    with pytest.raises(
+        ValueError, match="All edges must be specified as either an input feature"
+    ):
+        ComponentGraph(
+            {
+                "Imputer": [Imputer, "X", "y"],
+                "One Hot Encoder": [OneHotEncoder, "Imputer.x", "y"],
+                "Target Imputer": [
+                    TargetImputer,
+                    "Imputer",  # offending line: "Imputer" not allowed
+                    "One Hot Encoder.x",
+                    "y",
+                ],
+                "Random Forest Classifier": [
+                    RandomForestClassifier,
+                    "One Hot Encoder.x",
+                    "Target Imputer.y",
+                ],
+            }
+        )
+
+
 def test_component_graph_defines_edge_with_invalid_syntax():
     # Graph does not define an X edge using .x
-    with pytest.raises(ValueError, match="All edges must be specified"):
+    with pytest.raises(
+        ValueError, match="All components must have at least one input feature"
+    ):
         ComponentGraph(
             {
                 "Imputer": [Imputer, "X", "y"],
@@ -2001,3 +2175,146 @@ def test_component_graph_repr():
     expected_repr = "{'Imputer': ['Imputer', 'X', 'y'], 'OHE': ['One Hot Encoder', 'Imputer.x', 'y'], 'Random Forest Classifier': ['Random Forest Classifier', 'OHE.x', 'y']}"
     component_graph = ComponentGraph(component_dict_with_objs)
     assert repr(component_graph) == expected_repr
+
+
+@patch("evalml.pipelines.components.estimators.LogisticRegressionClassifier.fit")
+@pytest.mark.parametrize("sampler", ["Undersampler", "SMOTE Oversampler"])
+def test_component_graph_compute_final_component_features_with_sampler(
+    mock_estimator_fit, sampler, has_minimal_dependencies
+):
+    if sampler == "SMOTE Oversampler" and has_minimal_dependencies:
+        pytest.importorskip(
+            "imblearn.over_sampling", reason="Cannot import imblearn, skipping tests"
+        )
+    expected_length = 750 if sampler == "Undersampler" else int(1.25 * 850)
+    X = pd.DataFrame([[i] for i in range(1000)])
+    y = pd.Series([0] * 150 + [1] * 850)
+    component_graph = {
+        sampler: [sampler, "X", "y"],
+        "Logistic Regression Classifier": [
+            "Logistic Regression Classifier",
+            f"{sampler}.x",
+            f"{sampler}.y",
+        ],
+    }
+
+    component_graph = ComponentGraph(component_graph)
+    component_graph.instantiate({})
+    component_graph.fit(X, y)
+    assert len(mock_estimator_fit.call_args[0][0]) == len(
+        mock_estimator_fit.call_args[0][1]
+    )
+    assert len(mock_estimator_fit.call_args[0][0]) == expected_length
+    features_for_estimator = component_graph.compute_final_component_features(X, y)
+    assert len(features_for_estimator) == len(y)
+
+
+@patch("evalml.pipelines.components.Imputer.transform")
+@patch("evalml.pipelines.components.OneHotEncoder.transform")
+@patch("evalml.pipelines.components.RandomForestClassifier.predict")
+def test_component_graph_transform(
+    mock_rf_predict,
+    mock_ohe_transform,
+    mock_imputer_transform,
+    X_y_binary,
+    make_data_type,
+):
+    X, y = X_y_binary
+
+    X = make_data_type("ww", X)
+    y = make_data_type("ww", y)
+
+    dummy_return_value = pd.DataFrame({"test df": [1, 2]})
+    mock_imputer_transform.return_value = X
+    mock_ohe_transform.return_value = dummy_return_value
+    component_dict = {
+        "Imputer": ["Imputer", "X", "y"],
+        "OHE": ["One Hot Encoder", "Imputer.x", "y"],
+    }
+
+    mock_rf_predict.return_value = y
+
+    component_graph = ComponentGraph(component_dict)
+    component_graph.instantiate({})
+    component_graph.fit(X, y)
+    transformed_X = component_graph.transform(X, y)
+    assert_frame_equal(transformed_X, dummy_return_value)
+
+    component_dict_with_estimator = {
+        "Imputer": ["Imputer", "X", "y"],
+        "Random Forest Classifier": ["Random Forest Classifier", "Imputer.x", "y"],
+        "OHE": ["One Hot Encoder", "Random Forest Classifier.x", "y"],
+    }
+    component_graph = ComponentGraph(component_dict_with_estimator)
+    component_graph.instantiate({})
+    component_graph.fit(X, y)
+    transformed_X = component_graph.transform(X, y)
+    assert_frame_equal(transformed_X, dummy_return_value)
+
+
+@patch("evalml.pipelines.components.Imputer.transform")
+@patch("evalml.pipelines.components.OneHotEncoder.transform")
+@patch("evalml.pipelines.components.TargetImputer.transform")
+def test_component_graph_transform_with_target_transformer(
+    mock_target_imputer_transform,
+    mock_ohe_transform,
+    mock_imputer_transform,
+    X_y_binary,
+    make_data_type,
+):
+    X, y = X_y_binary
+    X = make_data_type("ww", X)
+    y = make_data_type("ww", y)
+
+    component_dict = {
+        "Imputer": ["Imputer", "X", "y"],
+        "OHE": ["One Hot Encoder", "Imputer.x", "y"],
+        "Target Imputer": ["Target Imputer", "OHE.x", "y"],
+    }
+    mock_imputer_transform.return_value = X
+    mock_ohe_transform.return_value = X
+    mock_target_imputer_transform.return_value = tuple([X, y])
+
+    component_graph = ComponentGraph(component_dict)
+    component_graph.instantiate({})
+    component_graph.fit(X, y)
+    transformed = component_graph.transform(X, y)
+    assert_frame_equal(transformed[0], X)
+    assert_series_equal(transformed[1], y)
+
+
+def test_component_graph_transform_with_estimator_end(X_y_binary):
+    X, y = X_y_binary
+    component_dict = {
+        "Imputer": ["Imputer", "X", "y"],
+        "OHE": ["One Hot Encoder", "Imputer.x", "y"],
+        "RF": ["Random Forest Classifier", "OHE.x", "y"],
+    }
+    component_graph = ComponentGraph(component_dict)
+    component_graph.instantiate({})
+    component_graph.fit(X, y)
+    with pytest.raises(
+        ValueError,
+        match=re.escape(
+            "Cannot call transform() on a component graph because the final component is not a Transformer."
+        ),
+    ):
+        component_graph.transform(X, y)
+
+
+def test_component_graph_predict_with_transformer_end(X_y_binary):
+    X, y = X_y_binary
+    component_dict = {
+        "Imputer": ["Imputer", "X", "y"],
+        "OHE": ["One Hot Encoder", "Imputer.x", "y"],
+    }
+    component_graph = ComponentGraph(component_dict)
+    component_graph.instantiate({})
+    component_graph.fit(X, y)
+    with pytest.raises(
+        ValueError,
+        match=re.escape(
+            "Cannot call predict() on a component graph because the final component is not an Estimator."
+        ),
+    ):
+        component_graph.predict(X)
